@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from contextlib import contextmanager
+import argparse
 from dataclasses import dataclass, field, replace
 import enum
 from functools import lru_cache
@@ -8,46 +8,40 @@ import os
 import os.path as P
 import re
 import sys
-import traceback
 from typing import (
-    Any, ClassVar, Iterator, NoReturn, TYPE_CHECKING, TextIO, Type, TypeVar
+    Any,
+    Callable,
+    ClassVar,
+    Iterable,
+    NoReturn,
+    Sequence,
+    TYPE_CHECKING,
+    TextIO,
+    TypeVar,
 )
 
 
-liblktlang_available = True
-try:
-    import liblktlang as L
-except (ImportError, OSError):
-    # ImportError may be raised if liblktlang is not available.
-    #
-    # OSError may be raised if liblktlang is available, but the underlying
-    # dynamic library is missing dependency libraries. This can occur if the
-    # library was built with one version of the compiler, and then the compiler
-    # installation gets updated.  liblktlang has stale library links and fails
-    # to load.
-    #
-    # In both scenarios, assume liblktlang is not available and continue.
-    liblktlang_available = False
-
-
 from langkit.utils import Colors, assert_type, col
 
 
 if TYPE_CHECKING:
+    from langkit.compile_context import CompileCtx
     from langkit.compiled_types import CompiledType
     from langkit.expressions import PropertyDef
 
+    import liblktlang as L
+
 
 class DiagnosticStyle(enum.Enum):
     """Format for diagnostics that Langkit emits: location and text."""
 
-    default = 'default'
+    default = "default"
     """Human-readable tracebacks."""
 
-    gnu_full = 'gnu-full'
+    gnu_full = "gnu-full"
     """Standard GNU format with full paths."""
 
-    gnu_base = 'gnu-base'
+    gnu_base = "gnu-base"
     """Standard GNU format with basenames."""
 
 
@@ -57,6 +51,7 @@ class Diagnostics:
     be called by manage before functions depending on knowing the language
     source dir can be called.
     """
+
     has_pending_error = False
 
     style = DiagnosticStyle.default
@@ -66,61 +61,6 @@ class Diagnostics:
     :type: DiagnosticStyle
     """
 
-    blacklisted_paths = [P.dirname(P.abspath(__file__))]
-    """
-    List of blacklisted paths. Add to that list to keep paths out of
-    diagnostics.
-    """
-
-    blacklisted_frames: dict[str, set[int]] = {}
-    """
-    Mapping from filename to set of line numbers for all stack frames to
-    blacklist from DSL locations.
-    """
-
-    @classmethod
-    def blacklist_frame(cls, frame: traceback.FrameSummary) -> None:
-        """
-        Add the given frame to blacklisted ones for DSL locations.
-        """
-        if isinstance(frame.lineno, int):
-            filename = P.normpath(frame.filename)
-            lineno_set = cls.blacklisted_frames.setdefault(filename, set())
-            lineno_set.add(frame.lineno)
-
-    @classmethod
-    def is_langkit_dsl(cls, frame: traceback.FrameSummary) -> bool:
-        """
-        Return whether to exclude the given frame from locations used to create
-        diagnostics.
-        """
-        # If the path of the file is in the list of blacklisted paths, then
-        # it's definitely not part of the language spec.
-        python_file = P.normpath(frame.filename)
-        if any(path in python_file for path in cls.blacklisted_paths):
-            return False
-
-        # Never use blacklisted stack frames to create DSL locations
-        try:
-            linenos = cls.blacklisted_frames[python_file]
-        except KeyError:
-            pass
-        else:
-            if frame.lineno in linenos:
-                return False
-
-        # The "manage.py" script is supposed to define settings for the
-        # language spec, but is not the language spec itself.
-        if "manage.py" in python_file:
-            return False
-
-        # Reject Python internals, definitely not part of the language spec
-        # neither. For instance: "<frozen importlib._bootstrap>".
-        if python_file.startswith("<"):
-            return False
-
-        return True
-
     @classmethod
     def set_style(cls, style: DiagnosticStyle) -> None:
         """
@@ -179,9 +119,9 @@ class Location:
         return ":".join(parts)
 
     @classmethod
-    def from_sloc_range(cls,
-                        unit: L.AnalysisUnit,
-                        sloc: L.SlocRange) -> Location:
+    def from_sloc_range(
+        cls, unit: L.AnalysisUnit, sloc: L.SlocRange
+    ) -> Location:
         """
         Create a Location based on a LKT SlocRange and AnalysisUnit.
         """
@@ -191,7 +131,7 @@ class Location:
             sloc.start.column,
             sloc.end.line,
             sloc.end.column,
-            unit
+            unit,
         )
 
     @classmethod
@@ -201,6 +141,23 @@ class Location:
         """
         return cls.from_sloc_range(node.unit, node.sloc_range)
 
+    @classmethod
+    def from_lkt_node_range(cls, start: L.LktNode, end: L.LktNode) -> Location:
+        """
+        Create a Location from the range that two Lkt nodes cover.
+        """
+        unit = start.unit
+        start_sloc = start.sloc_range
+        end_sloc = end.sloc_range
+        return cls(
+            unit.filename,
+            start_sloc.start.line,
+            start_sloc.start.column,
+            end_sloc.end.line,
+            end_sloc.end.column,
+            unit,
+        )
+
     @classmethod
     def from_lkt_node_or_none(cls, node: L.LktNode | None) -> Location | None:
         """
@@ -209,11 +166,33 @@ class Location:
         """
         return None if node is None else cls.from_lkt_node(node)
 
+    @classmethod
+    def from_lkt_tokens(
+        cls,
+        n: L.LktNode,
+        start: L.Token,
+        end: L.Token,
+    ) -> Location:
+        """
+        Create a Location from the range that two Lkt tokens cover.
+        """
+        unit = n.unit
+        start_loc = start.sloc_range.start
+        end_loc = end.sloc_range.end
+        return cls(
+            unit.filename,
+            start_loc.line,
+            start_loc.column,
+            end_loc.line,
+            end_loc.column,
+            unit,
+        )
+
     @classmethod
     def for_entity_doc(
         cls,
         entity: CompiledType | PropertyDef,
-    ) -> Location | None:
+    ) -> Location:
         """
         Return the location of the docstring for the given entity, if
         available.
@@ -226,9 +205,11 @@ class Location:
         # declaration's first line ("class" keyword or "def" one), and the
         # docstring first line (just the """ string delimiter) is stripped.
         result = entity.location
-        if result is not None:
-            result = replace(result, line=result.line + 2)
-        return result
+        return (
+            Location.unknown
+            if result is None
+            else replace(result, line=result.line + 2)
+        )
 
     @staticmethod
     def resolve(location: Location | L.LktNode) -> Location:
@@ -237,11 +218,13 @@ class Location:
         instance. Note that this possible only if liblktlang is available, so
         we know that we'll have a Location instance afterwards.
         """
-        if liblktlang_available and isinstance(location, L.LktNode):
-            return Location.from_lkt_node(location)
-        else:
-            assert isinstance(location, Location)
+        if isinstance(location, Location):
             return location
+        else:
+            import liblktlang as L
+
+            assert isinstance(location, L.LktNode)
+            return Location.from_lkt_node(location)
 
     builtin: ClassVar[Location]
     """
@@ -255,48 +238,19 @@ class Location:
     that do not relate to a specific place in source code.
     """
 
+    unknown: ClassVar[Location]
+    """
+    Special location to designate an entity that comes from the language spec,
+    but at an unknown location.
+
+    TODO (eng/libadalang/langkit#880): this should disappear once the Python
+    DSL is retired.
+    """
+
 
 Location.builtin = Location("<builtin>")
 Location.nowhere = Location("")
-
-
-def extract_library_location(
-    stack: list[Any] | None = None
-) -> Location | None:
-    """
-    Extract the location of the definition of an entity in the language
-    specification from a stack trace. Use `traceback.extract_stack()` if no
-    stack is provided.
-    """
-    stack = stack or traceback.extract_stack()
-
-    # Create Location instances for each stack frame
-    locs = [Location(file=t.filename, line=t.lineno)
-            for t in stack
-            if isinstance(t.lineno, int) and Diagnostics.is_langkit_dsl(t)]
-
-    return locs[-1] if locs else None
-
-
-context_stack: list[Location | None] = []
-
-
-@contextmanager
-def diagnostic_context(location: Location | None) -> Iterator[None]:
-    """
-    Context manager to temporarily append a location to the context stack for
-    diagnostics.
-
-    :param location: The location for diagnostics.
-    """
-    if location is not None:
-        context_stack.append(location)
-        try:
-            yield
-        finally:
-            context_stack.pop()
-    else:
-        yield
+Location.unknown = Location("<unknown>")
 
 
 class DiagnosticError(Exception):
@@ -308,37 +262,40 @@ class Severity(enum.IntEnum):
     Severity of a diagnostic. For the moment we have two levels, warning and
     error. A warning won't end the compilation process, and error will.
     """
+
     warning = 1
     error = 2
     non_blocking_error = 3
 
 
 SEVERITY_COLORS = {
-    Severity.warning:            Colors.YELLOW,
-    Severity.error:              Colors.RED,
+    Severity.warning: Colors.YELLOW,
+    Severity.error: Colors.RED,
     Severity.non_blocking_error: Colors.RED,
 }
 
 
 def format_severity(severity: Severity) -> str:
-    msg = ('Error'
-           if severity == Severity.non_blocking_error else
-           severity.name.capitalize())
+    msg = (
+        "Error"
+        if severity == Severity.non_blocking_error
+        else severity.name.capitalize()
+    )
     return col(msg, Colors.BOLD + SEVERITY_COLORS[severity])
 
 
-def get_structured_context() -> list[Location]:
+def coerce_location(location: Location | L.LktNode) -> Location:
     """
-    From the context global structures, return a structured context locations
-    list.
+    If given a location, just return it. If given a Lkt node, return its
+    location.
     """
-    return list(l for l in reversed(context_stack) if l)
+    if isinstance(location, Location):
+        return location
+    else:
+        import liblktlang as L
 
-
-def get_current_location() -> Location:
-    ctx = get_structured_context()
-    assert ctx
-    return ctx[0]
+        assert isinstance(location, L.LktNode)
+        return Location.from_lkt_node(location)
 
 
 def get_parsable_location(location: Location | L.LktNode) -> str:
@@ -350,47 +307,83 @@ def get_parsable_location(location: Location | L.LktNode) -> str:
     Depending on the diagnostic style enabled, `file` will be a base name or a
     full path. Note that this should not be run when `DiagnosticStyle.default`
     is enabled.
-
-    :rtype: str
     """
     assert Diagnostics.style != DiagnosticStyle.default
-    loc = get_current_location()
+    loc = coerce_location(location)
     if loc:
-        path = (P.abspath(loc.file)
-                if Diagnostics.style == DiagnosticStyle.gnu_full else
-                P.basename(loc.file))
+        path = (
+            P.abspath(loc.file)
+            if Diagnostics.style == DiagnosticStyle.gnu_full
+            else P.basename(loc.file)
+        )
         return "{}:{}:1".format(path, loc.line)
     else:
         return ""
 
 
-def error(message: str, ok_for_codegen: bool = False) -> NoReturn:
+def error(
+    message: str,
+    location: Location | L.LktNode,
+    ok_for_codegen: bool = False,
+) -> NoReturn:
     """
     Shortcut around ``check_source_language``, for fatal errors.
     """
-    check_source_language(False, message, ok_for_codegen=ok_for_codegen)
+    check_source_language(
+        False,
+        message,
+        location,
+        ok_for_codegen=ok_for_codegen,
+    )
     # NOTE: The following raise is useless, but is there because mypy is not
     # clever enough to know  that the previous call will never return.
     raise AssertionError("should not happen")
 
 
-def non_blocking_error(message: str, ok_for_codegen: bool = False) -> None:
+def emit_error(
+    message: str,
+    location: Location | L.LktNode,
+    severity: Severity = Severity.error,
+    ok_for_codegen: bool = False,
+) -> None:
+    """
+    Like ``error()``, but not raising an exception.
+    """
+    check_source_language(
+        False,
+        message,
+        location,
+        severity=severity,
+        do_raise=False,
+        ok_for_codegen=ok_for_codegen,
+    )
+
+
+def non_blocking_error(
+    message: str,
+    location: Location | L.LktNode,
+    ok_for_codegen: bool = False,
+) -> None:
     """
     Shortcut around ``check_source_language``, for non-fatal errors.
     """
     check_source_language(
         False,
         message,
+        location=location,
         ok_for_codegen=ok_for_codegen,
         severity=Severity.non_blocking_error,
     )
 
 
-def check_source_language(predicate: bool,
-                          message: str,
-                          severity: Severity = Severity.error,
-                          do_raise: bool = True,
-                          ok_for_codegen: bool = False) -> None:
+def check_source_language(
+    predicate: bool,
+    message: str,
+    location: Location | L.LktNode,
+    severity: Severity = Severity.error,
+    do_raise: bool = True,
+    ok_for_codegen: bool = False,
+) -> None:
     """
     Check predicates related to the user's input in the input language
     definition. Show error messages and eventually terminate if those error
@@ -400,6 +393,7 @@ def check_source_language(predicate: bool,
     :param message: The base message to display if predicate happens to be
         false.
     :param severity: The severity of the diagnostic.
+    :param location: Location associated to the diagnostic to emit.
     :param do_raise: If True, raise a DiagnosticError if predicate happens to
         be false.
     :param ok_for_codegen: If True, allow checks to be performed during
@@ -412,20 +406,20 @@ def check_source_language(predicate: bool,
 
     if not ok_for_codegen:
         ctx = get_context_or_none()
-        assert ctx is None or ctx.emitter is None
+        assert ctx is None or not ctx.emission_started
 
     severity = assert_type(severity, Severity)
-    indent = ' ' * 4
+    indent = " " * 4
 
     if not predicate:
         message_lines = message.splitlines()
-        message = '\n'.join(
+        message = "\n".join(
             message_lines[:1] + [indent + line for line in message_lines[1:]]
         )
 
-        location = get_current_location()
+        location = coerce_location(location)
         if Diagnostics.style != DiagnosticStyle.default:
-            print('{}: {}'.format(get_parsable_location(location), message))
+            print("{}: {}".format(get_parsable_location(location), message))
         else:
             print_error(message, location, severity)
 
@@ -435,12 +429,56 @@ def check_source_language(predicate: bool,
             Diagnostics.has_pending_error = True
 
 
+@dataclass(frozen=True)
+class DiagnosticContext:
+    """
+    Shortcut to diagnostic-emitting routine calls that all share the same
+    location.
+    """
+
+    location: Location | L.LktNode
+
+    def error(self, message: str, ok_for_codegen: bool = False) -> NoReturn:
+        error(message, self.location, ok_for_codegen)
+
+    def emit_error(
+        self,
+        message: str,
+        severity: Severity = Severity.error,
+        ok_for_codegen: bool = False,
+    ) -> None:
+        emit_error(message, self.location, severity, ok_for_codegen)
+
+    def non_blocking_error(
+        self, message: str, ok_for_codegen: bool = False
+    ) -> None:
+        non_blocking_error(message, self.location, ok_for_codegen)
+
+    def check_source_language(
+        self,
+        predicate: bool,
+        message: str,
+        severity: Severity = Severity.error,
+        do_raise: bool = True,
+        ok_for_codegen: bool = False,
+    ) -> None:
+        check_source_language(
+            predicate,
+            message,
+            self.location,
+            severity,
+            do_raise,
+            ok_for_codegen,
+        )
+
+
 @dataclass(frozen=True)
 class WarningDescriptor:
     """
     Embed information about a class of warnings. Allows to log warning messages
     via the `warn_if` method.
     """
+
     name: str
     enabled_by_default: bool
     description: str
@@ -451,15 +489,25 @@ class WarningDescriptor:
         Return whether this warning is enabled in the current context.
         """
         from langkit.compile_context import get_context
+
         return self in get_context().warnings
 
-    def warn_if(self, predicate: bool, message: str) -> None:
+    def warn_if(
+        self,
+        predicate: bool,
+        message: str,
+        location: Location | L.LktNode,
+    ) -> None:
         """
         Helper around check_source_language, to raise warnings, depending on
         whether self is enabled or not in the current context.
         """
-        check_source_language(not self.enabled or not predicate, message,
-                              severity=Severity.warning)
+        check_source_language(
+            not self.enabled or not predicate,
+            message,
+            severity=Severity.warning,
+            location=location,
+        )
 
 
 class WarningSet:
@@ -468,51 +516,54 @@ class WarningSet:
     """
 
     prop_only_entities = WarningDescriptor(
-        'prop-only-entities', True,
-        'Warn about properties that return AST nodes.'
+        "prop-only-entities",
+        True,
+        "Warn about properties that return AST nodes.",
     )
     unused_bindings = WarningDescriptor(
-        'unused-bindings', True,
-        'Warn about bindings (in properties) that are unused, or the ones used'
-        ' while they are declared as unused.'
-    )
-    unparser_bad_grammar = WarningDescriptor(
-        'unparser-bad-grammar', False,
-        'Warn if the grammar is not amenable to the automatic generation of an'
-        ' unparser.'
+        "unused-bindings",
+        True,
+        "Warn about bindings (in properties) that are unused, or the ones used"
+        " while they are declared as unused.",
     )
     unused_node_type = WarningDescriptor(
-        'unused-node-type', True,
-        'Warn if a node type is not used in the grammar, and is not marked as'
-        ' abstract nor synthetic.'
+        "unused-node-type",
+        True,
+        "Warn if a node type is not used in the grammar, and is not marked as"
+        " abstract nor synthetic.",
     )
     undocumented_public_properties = WarningDescriptor(
-        'undocumented-public-properties', True,
-        'Warn if a public property is left undocumented.'
+        "undocumented-public-properties",
+        True,
+        "Warn if a public property is left undocumented.",
     )
     undocumented_nodes = WarningDescriptor(
-        'undocumented-nodes', True,
-        'Warn if a node is left undocumented.'
+        "undocumented-nodes", True, "Warn if a node is left undocumented."
     )
     imprecise_field_type_annotations = WarningDescriptor(
-        'imprecise-field-type-annotations', True,
-        'Warn about parsing field type annotations that are not as precise as'
-        ' they could be.'
+        "imprecise-field-type-annotations",
+        True,
+        "Warn about parsing field type annotations that are not as precise as"
+        " they could be.",
     )
     available_warnings = [
-        prop_only_entities, unused_bindings, unparser_bad_grammar,
-        unused_node_type, undocumented_public_properties, undocumented_nodes,
+        prop_only_entities,
+        unused_bindings,
+        unused_node_type,
+        undocumented_public_properties,
+        undocumented_nodes,
         imprecise_field_type_annotations,
     ]
 
     def __init__(self) -> None:
-        self.enabled_warnings = {w for w in self.available_warnings
-                                 if w.enabled_by_default}
+        self.enabled_warnings = {
+            w for w in self.available_warnings if w.enabled_by_default
+        }
 
     def __repr__(self) -> str:
-        return '<WarningSet [{}]>'.format(', '.join(
-            w.name for w in self.enabled_warnings
-        ))
+        return "<WarningSet [{}]>".format(
+            ", ".join(w.name for w in self.enabled_warnings)
+        )
 
     def enable(self, warning: WarningDescriptor | str) -> None:
         """
@@ -567,12 +618,15 @@ class WarningSet:
             if w.name == name:
                 return w
         else:
-            raise ValueError('Invalid warning: {}'.format(name))
+            raise ValueError("Invalid warning: {}".format(name))
 
     @classmethod
-    def print_list(cls,
-                   out: TextIO = sys.stdout,
-                   width: int | None = None) -> None:
+    def print_list(
+        cls,
+        context: CompileCtx,
+        out: TextIO = sys.stdout,
+        width: int | None = None,
+    ) -> None:
         """
         Display the list of available warnings in `f`.
 
@@ -585,47 +639,97 @@ class WarningSet:
 
         if width is None:
             try:
-                width = int(os.environ['COLUMNS'])
+                width = int(os.environ["COLUMNS"])
             except (KeyError, ValueError):
                 width = 80
-        print('List of available warnings:', file=out)
+        print("List of available warnings:", file=out)
         for w in cls.available_warnings:
-            print('', file=out)
-            print('* {}:'.format(w.name), file=out)
+            print("", file=out)
+            print("* {}:".format(w.name), file=out)
             if w.enabled_by_default:
-                print('  [enabled by default]', file=out)
-            print(langkit.documentation.format_text(w.description, 2, width),
-                  file=out)
+                print("  [enabled by default]", file=out)
+            print(
+                langkit.documentation.format_text(
+                    context, w.description, 2, width
+                ),
+                file=out,
+            )
+
+    @staticmethod
+    def add_args(
+        parser: argparse.ArgumentParser,
+        dest: str = "warning_activations",
+    ) -> None:
+        """
+        Register --enable-warning/--disable-warnings arguments in ``parser``.
+
+        Parsing these two options will yield a mapping from warning names to a
+        boolean that determines whether this warning should be enabled or
+        disabled and store that mapping in the "dest" argument namespace
+        attribute.
+        """
+
+        class Action(argparse.Action):
+            def __init__(
+                self,
+                option_strings: list[str],
+                dest: str,
+                nargs: int | str | None = None,
+                const: object = None,
+                default: object = None,
+                type: (
+                    Callable[[str], object] | argparse.FileType | None
+                ) = None,
+                choices: Iterable[object] | None = None,
+                required: bool = False,
+                help: str | None = None,
+                metavar: str | None = None,
+            ):
+                assert isinstance(const, bool)
+                super().__init__(
+                    option_strings,
+                    dest,
+                    nargs,
+                    const,
+                    default,
+                    type,
+                    choices,
+                    required,
+                    help,
+                    metavar,
+                )
+
+            def __call__(
+                self,
+                parser: argparse.ArgumentParser,
+                namespace: argparse.Namespace,
+                values: str | Sequence[Any] | None,
+                option_string: str | None = None,
+            ) -> None:
+                assert isinstance(values, str)
+                mapping = getattr(namespace, self.dest)
+                mapping[values] = self.const
+
+        parser.add_argument(
+            "--enable-warning",
+            "-W",
+            help="Activate a warning by name.",
+            dest=dest,
+            default={},
+            action=Action,
+            const=True,
+        )
+        parser.add_argument(
+            "--disable-warning",
+            "-w",
+            help="Deactivate a warning by name.",
+            dest=dest,
+            action=Action,
+            const=False,
+        )
 
 
-def check_multiple(predicates_and_messages: list[tuple[bool, str]],
-                   severity: Severity = Severity.error) -> None:
-    """
-    Helper around check_source_language, check multiple predicates at once.
-
-    :param predicates_and_messages: List of diagnostic tuples.
-    :param severity: The severity of the diagnostics.
-    """
-    for predicate, message in predicates_and_messages:
-        check_source_language(predicate, message, severity)
-
-
-T = TypeVar('T')
-
-
-def check_type(obj: Any, typ: Type[T], message: str | None = None) -> T:
-    """
-    Like utils.assert_type, but produces a client error instead.
-
-    :param obj: The object to check.
-    :param typ: The expected type of obj.
-    :param str|None message: The base message to display if type check fails.
-    """
-    try:
-        return assert_type(obj, typ)
-    except AssertionError as e:
-        message = "{}\n{}".format(e.args[0], message) if message else e.args[0]
-        error(message)
+T = TypeVar("T")
 
 
 def errors_checkpoint() -> None:
@@ -672,7 +776,7 @@ def source_listing(
 
     # Make sure we have at least one line, since locations can refer to "line
     # 1" even for empty source files.
-    source_buffer = splitted_text(highlight_sloc.lkt_unit) or ['']
+    source_buffer = splitted_text(highlight_sloc.lkt_unit) or [""]
 
     ret = []
 
@@ -704,8 +808,12 @@ def source_listing(
         # need to see.
         displayed_line_nb = "" if line_nb is None else str(line_nb + 1)
 
-        ret.append(col(prefix_fmt.format(displayed_line_nb, line),
-                       Colors.BLUE + Colors.BOLD))
+        ret.append(
+            col(
+                prefix_fmt.format(displayed_line_nb, line),
+                Colors.BLUE + Colors.BOLD,
+            )
+        )
         ret.append(line)
         ret.append("\n")
 
@@ -722,26 +830,29 @@ def source_listing(
 
     # Append following lines up to ``lines_after`` lines
     for cur_line_nb, cur_line in enumerate(
-        source_buffer[line_nb + 1:
-                      min(line_nb + lines_after + 1, len(source_buffer))],
-        line_nb + 1
+        source_buffer[
+            line_nb + 1 : min(line_nb + lines_after + 1, len(source_buffer))
+        ],
+        line_nb + 1,
     ):
         append_line(cur_line_nb, cur_line)
 
     return "".join(ret)
 
 
-def print_error(message: str,
-                location: Location | L.LktNode,
-                severity: Severity = Severity.error) -> None:
+def print_error(
+    message: str,
+    location: Location | L.LktNode,
+    severity: Severity = Severity.error,
+) -> None:
     """
     Prints an error.
     """
     if severity == Severity.warning:
-        name = 'warning'
+        name = "warning"
         color = Colors.YELLOW
     else:
-        name = 'error'
+        name = "error"
         color = Colors.RED
     error_marker = col("{}: ".format(name), color + Colors.BOLD)
 
@@ -767,13 +878,10 @@ def print_error(message: str,
             print(src_lst)
 
 
-def print_error_from_sem_result(sem_result: L.SemanticResult) -> None:
+def print_error_from_sem_result(sdiag: L.SolverDiagnostic) -> None:
     """
     Emit an error from an Lkt semantic result.
     """
-    with diagnostic_context(
-        Location.from_lkt_node(sem_result.node)
-    ):
-        check_source_language(False,
-                              sem_result.error_message,
-                              severity=Severity.non_blocking_error)
+    non_blocking_error(
+        sdiag.message_template.format(*sdiag.args), location=sdiag.location
+    )
