@@ -14,8 +14,9 @@ if TYPE_CHECKING:
 
 
 class _Logger(Protocol):
-    def __call__(self, message: str, *args: object, **kwargs: object) -> None:
-        ...
+    def __call__(
+        self, message: str, *args: object, **kwargs: object
+    ) -> None: ...
 
 
 class Log:
@@ -23,22 +24,26 @@ class Log:
     This class is a relatively generic logging handler. It includes decorators
     and context managers to make logging easier.
     """
+
     enabled: ClassVar[dict[str, bool]] = defaultdict(bool)
     nesting_level: ClassVar[int] = 0
 
     @staticmethod
     def log_return(
-        trace: str
+        trace: str,
     ) -> Callable[[Callable[_P, _T]], Callable[_P, _T]]:
         """
         Decorates a function, so that its return value is logged.
         """
+
         def decorator(fn: Callable[_P, _T]) -> Callable[_P, _T]:
             def internal(*args: _P.args, **kwargs: _P.kwargs) -> _T:
                 ret = fn(*args, **kwargs)
                 Log.log(trace, "{} returned {}".format(fn.__name__, ret))
                 return ret
+
             return internal
+
         return decorator
 
     @staticmethod
@@ -80,7 +85,9 @@ class Log:
         Decorator for recursive functions that use logging. Every call to the
         function will increase the nesting level by 1.
         """
+
         def internal(*args: _P.args, **kwargs: _P.kwargs) -> _T:
             with Log.nest():
                 return fn(*args, **kwargs)
+
         return internal
