@@ -17,9 +17,4 @@ class LktCompileDriver(PythonDriver):
 
     @property
     def script_and_args(self):
-        result = [os.path.join(self.support_dir, "lkt_compile.py")]
-        if self.test_env.get("all_warnings"):
-            result.append("--all-warnings")
-        if self.test_env.get("generate_unparser"):
-            result.append("--generate-unparser")
-        return result
+        return [os.path.join(self.support_dir, "lkt_compile.py")]
