@@ -6,7 +6,7 @@ recursive calls: they must trigger in the same call.
 """
 
 from helpers import (
-    break_dsl,
+    break_lkt,
     run_continue,
     run_foonext,
     run_fooout,
@@ -20,7 +20,7 @@ gdb = start_gdb("recursive_cf")
 def setup(label: str):
     # Run the test program until the given label
     gdb.test("start recursive_cf", None)
-    break_dsl(label)
+    break_lkt(label)
     run_continue()
 
     # Delete the breakpoint so that it does not trigger during recursive calls:
@@ -32,7 +32,7 @@ def setup(label: str):
 
 
 def check_in_root():
-    gdb.test("foostate self", "self = <FooNodeList main.txt:1:1-1:27>")
+    gdb.test("foostate node", "node = <FooNodeList main.txt:1:1-1:27>")
 
 
 ########
@@ -41,10 +41,10 @@ def check_in_root():
 
 setup("recursive_inner_loop")
 run_foonext(
-    "<FieldAccess for test_recursive_cf at test.lkt:@NUMBER:@NUMBER> evaluated"
+    "<FooNode.test_recursive_cf at test.lkt:@NUMBER> evaluated"
     " to: 2"
     "\n"
-    "\nNow evaluating <Map at test.lkt:@NUMBER:@NUMBER>"
+    "\nNow evaluating <.map at test.lkt:@NUMBER>"
 )
 check_in_root()
 
@@ -54,16 +54,16 @@ check_in_root()
 
 setup("recursive_inner_loop")
 run_fooout(
-    "<FieldAccess for test_recursive_cf at test.lkt:@NUMBER:@NUMBER> evaluated"
+    "<FooNode.test_recursive_cf at test.lkt:@NUMBER> evaluated"
     " to: 2"
     "\n"
-    "\nNow evaluating <Map at test.lkt:@NUMBER:@NUMBER>"
+    "\nNow evaluating <.map at test.lkt:@NUMBER>"
 )
 check_in_root()
 run_fooout(
-    "<Map at test.lkt:@NUMBER:@NUMBER> evaluated to:"
+    "<.map at test.lkt:@NUMBER> evaluated to:"
     " Integer array of length 2 = {2, 1}"
     "\n"
-    "\nNow evaluating <Let at test.lkt:@NUMBER:@NUMBER>"
+    "\nNow evaluating <ValDecl at test.lkt:@NUMBER>"
 )
 check_in_root()
