@@ -3,10 +3,10 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_buffer('main.txt', b"""example""")
+u = ctx.get_from_buffer("main.txt", b"""example""")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
@@ -14,13 +14,13 @@ if u.diagnostics:
 
 iter_of_iter = u.root.p_test_struct_iterator
 
-print('Parsing new unit')
-u = ctx.get_from_buffer('main2.txt', b"""example""")
+print("Parsing new unit")
+u = ctx.get_from_buffer("main2.txt", b"""example""")
 
-print('Trying to iterate...')
+print("Trying to iterate...")
 try:
     print(next(iter_of_iter))
 except libfoolang.StaleReferenceError:
-    print('Got a StaleReferenceError')
+    print("Got a StaleReferenceError")
 
-print('main.py: Done.')
+print("main.py: Done.")
