@@ -3,10 +3,10 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_file('input')
+u = ctx.get_from_file("input")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
@@ -16,4 +16,4 @@ u.populate_lexical_env()
 for i in u.root.findall(libfoolang.Id):
     print("Scope for {}: {}".format(i, i.p_get_scope))
 
-print('main.py: Done.')
+print("main.py: Done.")
