@@ -6,12 +6,15 @@ import libfoolang
 print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_buffer("main.txt", buffer=b"""
+u = ctx.get_from_buffer(
+    "main.txt",
+    buffer=b"""
     def example example
     def example +example
     def +example example
     def +example +example
-""")
+""",
+)
 if u.diagnostics:
     for d in u.diagnostics:
         print("{}:{}".format(u.filename, d))
