@@ -3,11 +3,12 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
 u = ctx.get_from_buffer(
-    'main.txt', buffer=b"""
+    "main.txt",
+    buffer=b"""
         foo {
             bar {
                 bar0
@@ -15,21 +16,21 @@ u = ctx.get_from_buffer(
             baz {}
             qux
         }
-    """
+    """,
 )
 if u.diagnostics:
     for d in u.diagnostics:
-        print('{}:{}'.format(u.filename, d))
+        print("{}:{}".format(u.filename, d))
     sys.exit(1)
-print('== Before PLE ==')
+print("== Before PLE ==")
 sys.stdout.flush()
 u._dump_lexical_env()
-print('')
+print("")
 
-print('== After PLE ==')
+print("== After PLE ==")
 sys.stdout.flush()
 u.populate_lexical_env()
 u._dump_lexical_env()
-print('')
+print("")
 
-print('main.py: Done.')
+print("main.py: Done.")
