@@ -3,10 +3,10 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_file('main.txt')
+u = ctx.get_from_file("main.txt")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
@@ -21,4 +21,4 @@ print(baz.f_name.text + " has the following metadata:")
 print("  - foo_node: " + baz.p_get_foo_metadata.f_name.text)
 print("  - bar_node: " + baz.p_get_bar_metadata.f_name.text)
 
-print('main.py: Done.')
+print("main.py: Done.")
