@@ -3,10 +3,10 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_buffer('main.txt', b'example')
+u = ctx.get_from_buffer("main.txt", b"example")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
@@ -47,4 +47,4 @@ for prop_name, b1, b2, n in [
         f"{prop_name}({image(b1)}, {image(b2)}, {image(n)}) = {result_image}"
     )
 
-print('main.py: Done.')
+print("main.py: Done.")
