@@ -3,10 +3,10 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_buffer('main.txt', b'(example)')
+u = ctx.get_from_buffer("main.txt", b"(example)")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
@@ -15,4 +15,4 @@ if u.diagnostics:
 n = u.root
 print("p_prop =", n.p_prop)
 
-print('main.py: Done.')
+print("main.py: Done.")
