@@ -3,7 +3,7 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 
 def load_unit(filename, content):
@@ -18,21 +18,23 @@ def load_unit(filename, content):
 
 ctx = libfoolang.AnalysisContext()
 ctx.discard_errors_in_populate_lexical_env(False)
-unit_a = load_unit('a.txt', b'a (b)')
-unit_b = load_unit('b.txt', b'b (a)')
+unit_a = load_unit("a.txt", b"a (b)")
+unit_b = load_unit("b.txt", b"b (a)")
 
 # Make unit_a memoize a lexical environment that belong to unit_b
-print('unit_a references: {}'.format(
-    [n.p_referenced for n in unit_a.root.f_content]
-))
+print(
+    "unit_a references: {}".format(
+        [n.p_referenced for n in unit_a.root.f_content]
+    )
+)
 
-print('Reparse unit_b')
-unit_b.reparse(b'')
+print("Reparse unit_b")
+unit_b.reparse(b"")
 
 # And then unit_a: we expect the destroy mechanism not to try to dec-ref the
 # memoization slot, which point to a lexical environment that has been
 # deallocated.
-print('Reparse unit_a')
-unit_a.reparse(b'')
+print("Reparse unit_a")
+unit_a.reparse(b"")
 
-print('main.py: Done.')
+print("main.py: Done.")
