@@ -3,14 +3,14 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
-u = ctx.get_from_buffer('main.txt', b'example')
+u = ctx.get_from_buffer("main.txt", b"example")
 if u.diagnostics:
     for d in u.diagnostics:
         print(d)
     sys.exit(1)
 
-print('prop = {}'.format(u.root.p_prop))
-print('main.py: Done.')
+print("prop = {}".format(u.root.p_prop))
+print("main.py: Done.")
