@@ -3,7 +3,7 @@ import sys
 import libfoolang
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 
 ctx = libfoolang.AnalysisContext()
 u = ctx.get_from_buffer("main.txt", "example")
@@ -27,4 +27,4 @@ for strings, separator in [
     result = u.root.p_join(strings_arg, separator)
     print(f"join({strings}, {repr(separator)}) = {repr(result)}")
 
-print('main.py: Done.')
+print("main.py: Done.")
