@@ -1,4 +1,3 @@
-
 import sys
 
 import libfoolang
@@ -13,10 +12,10 @@ def load_unit(name, buffer):
     return u
 
 
-print('main.py: Running...')
+print("main.py: Running...")
 ctx = libfoolang.AnalysisContext()
-u = load_unit('main1.txt', b'example')
-s = libfoolang.KV(key='foo', value=10)
+u = load_unit("main1.txt", b"example")
+s = libfoolang.KV(key="foo", value=10)
 print(s)
 print(u.root[0].p_increment(s))
-print('main.py: Done')
+print("main.py: Done")
